@@ -14,8 +14,11 @@ pub enum WorkflowError {
     ExportsNeedsNoteFile,
 
     /// Remedy: restart with `--debug trace`.
-    #[error("Failed to render template! (cf. `{tmpl}` in configuration file).\n{source}")]
-    Template { tmpl: String, source: NoteError },
+    #[error("Failed to render template (cf. `{tmpl_name}` in configuration file)!\n{source}")]
+    Template {
+        tmpl_name: String,
+        source: NoteError,
+    },
 
     /// Forward `MissingFrontMatter` from `NoteError`.
     #[error(transparent)]
@@ -146,6 +149,21 @@ pub enum FileError {
 /// note file. This constant limits the number of text lines that are printed.
 pub const FRONT_MATTER_ERROR_MAX_LINES: usize = 20;
 
+/// Macro to construct a `NoteError::TeraTemplate from a `Tera::Error` .
+#[macro_export]
+macro_rules! note_error_tera_template {
+    ($e:ident) => {
+        NoteError::TeraTemplate {
+            source_str: std::error::Error::source(&$e)
+                .unwrap_or(&tera::Error::msg(""))
+                .to_string()
+                // Remove useless information.
+                .trim_end_matches("in context while rendering '__tera_one_off'")
+                .to_string(),
+        }
+    };
+}
+
 #[derive(Debug, Error)]
 /// Error type returned form methods in or related to the `note` module.
 pub enum NoteError {
@@ -154,10 +172,7 @@ pub enum NoteError {
     Read { path: PathBuf, source: io::Error },
 
     /// Remedy: check the syntax of the Tera template in the configuration file.
-    #[error(
-        "Tera template error:\n\
-         {source_str}"
-    )]
+    #[error("Tera template error: {source_str}")]
     TeraTemplate { source_str: String },
 
     /// Remedy: restart with `--debug trace`.
